"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRuntimeMessage = exports.createRoomLeaveMessage = exports.createRoomJoinMessage = exports.createNackMessage = void 0;
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
const protocol_definitions_1 = require("@fluidframework/protocol-definitions");
/**
 * @internal
 */
const createNackMessage = (code, type, message, retryAfterInSec) => ({
    operation: undefined,
    sequenceNumber: -1,
    content: {
        code,
        type,
        message,
        retryAfter: retryAfterInSec,
    },
});
exports.createNackMessage = createNackMessage;
/**
 * @internal
 */
function createRoomJoinMessage(clientId, client) {
    const joinContent = {
        clientId,
        client,
    };
    return {
        clientId: null,
        content: JSON.stringify({
            type: protocol_definitions_1.MessageType.ClientJoin,
            content: joinContent,
        }),
    };
}
exports.createRoomJoinMessage = createRoomJoinMessage;
/**
 * @internal
 */
const createRoomLeaveMessage = (clientId) => ({
    clientId: null,
    content: JSON.stringify({
        type: protocol_definitions_1.MessageType.ClientLeave,
        content: clientId,
    }),
});
exports.createRoomLeaveMessage = createRoomLeaveMessage;
/**
 * Template for runtime messages to be sent to an ongoing client collaboration session.
 */
const createRuntimeMessage = (signalContent) => ({
    // clientId is null here as it is set by the server which doesn't have information about the sender
    clientId: null,
    content: JSON.stringify({
        type: "RuntimeMessage",
        contents: signalContent.contents,
    }),
});
exports.createRuntimeMessage = createRuntimeMessage;
//# sourceMappingURL=messageGenerator.js.map