"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.logCommonSessionEndMetrics = exports.createSessionMetric = void 0;
const server_services_core_1 = require("@fluidframework/server-services-core");
const server_services_telemetry_1 = require("@fluidframework/server-services-telemetry");
/**
 * @internal
 */
const createSessionMetric = (tenantId, documentId, lumberEventName, serviceConfiguration) => {
    if (!serviceConfiguration.enableLumberjack) {
        return;
    }
    const sessionMetric = server_services_telemetry_1.Lumberjack.newLumberMetric(lumberEventName);
    sessionMetric?.setProperties({
        [server_services_telemetry_1.BaseTelemetryProperties.tenantId]: tenantId,
        [server_services_telemetry_1.BaseTelemetryProperties.documentId]: documentId,
    });
    return sessionMetric;
};
exports.createSessionMetric = createSessionMetric;
/**
 * @internal
 */
const logCommonSessionEndMetrics = (context, closeType, sessionMetric, sequenceNumber, lastSummarySequenceNumber, activeNackMessageTypes) => {
    if (!sessionMetric) {
        return;
    }
    const contextError = context.getContextError();
    sessionMetric.setProperties({ [server_services_telemetry_1.CommonProperties.sessionEndReason]: closeType });
    sessionMetric.setProperties({ [server_services_telemetry_1.CommonProperties.sessionState]: server_services_telemetry_1.SessionState.end });
    sessionMetric.setProperties({ [server_services_telemetry_1.CommonProperties.sequenceNumber]: sequenceNumber });
    sessionMetric.setProperties({
        [server_services_telemetry_1.CommonProperties.lastSummarySequenceNumber]: lastSummarySequenceNumber,
    });
    if (contextError) {
        sessionMetric.error(`Session terminated due to ${contextError}`);
    }
    else if (closeType === server_services_core_1.LambdaCloseType.Error) {
        sessionMetric.error("Session terminated due to error");
    }
    else if (!closeType ||
        closeType === server_services_core_1.LambdaCloseType.Stop ||
        closeType === server_services_core_1.LambdaCloseType.Rebalance) {
        sessionMetric.setProperties({ [server_services_telemetry_1.CommonProperties.sessionState]: server_services_telemetry_1.SessionState.paused });
        sessionMetric.success("Session paused");
    }
    else if (closeType === server_services_core_1.LambdaCloseType.ActivityTimeout) {
        if (activeNackMessageTypes?.includes(server_services_core_1.NackMessagesType.SummaryMaxOps)) {
            sessionMetric.error("Session terminated due to inactivity while exceeding max ops since last summary");
        }
        else {
            sessionMetric.success("Session terminated due to inactivity");
        }
    }
    else {
        sessionMetric.error("Unknown session end state");
    }
};
exports.logCommonSessionEndMetrics = logCommonSessionEndMetrics;
//# sourceMappingURL=telemetryHelper.js.map