"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDocumentSessionValid = exports.isDocumentValid = void 0;
/**
 * Whether a document exists and is not functionally deleted.
 * @internal
 */
function isDocumentValid(document) {
    return !!document && !document.scheduledDeletionTime;
}
exports.isDocumentValid = isDocumentValid;
/**
 * Whether a document's active session aligns with the service's location.
 * @internal
 */
function isDocumentSessionValid(document, serviceConfiguration) {
    if (!serviceConfiguration.externalOrdererUrl || !document.session) {
        // No session location to validate.
        return true;
    }
    const isSessionInThisCluster = document.session.ordererUrl === serviceConfiguration.externalOrdererUrl;
    if (document.session.isSessionActive && isSessionInThisCluster) {
        return true;
    }
    if (!document.session.isSessionAlive) {
        // Session is not "alive", so client has bypassed discovery flow.
        // Other clients could be routed to alternate locations, resulting in "split-brain" scenario.
        // Prevent Deli from processing ops.
        return false;
    }
    return isSessionInThisCluster;
}
exports.isDocumentSessionValid = isDocumentSessionValid;
//# sourceMappingURL=validateDocument.js.map